==> nextcloud-app-mail-5.0.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/af.js <==
OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Ingebedde boodskap %s",
    "Important mail" : "Belangrike pos",
    "Unread mail" : "Ongeleesde pos",
    "Important" : "Belangrik",
    "Work" : "Werk",
    "Personal" : "Persoonlik",
    "To Do" : "Moet doen",
    "Later" : "Later",
    "Mail" : "Pos",
    "Mails" : "E-pos",
    "💌 A mail app for Nextcloud" : "💌 ’n E-postoep vir Nextcloud",
    "Save" : "Stoor",
    "Connect" : "Verbind",
    "Name" : "Naam",
    "Mail address" : "Posadres",
    "Password" : "Wagwoord",
    "Manual" : "Handmatig",
    "IMAP Settings" : "IMAP-instellings",
    "IMAP Host" : "IMAP-gasheer",
    "IMAP Security" : "IMAP-sekuriteit",
    "None" : "Geen",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-poort",
    "IMAP User" : "IMAP-gebruiker",
    "IMAP Password" : "IMAP-wagwoord",
    "SMTP Settings" : "SMTP-instellings",
    "SMTP Host" : "SMTP-gasheer",
    "SMTP Security" : "SMTP-sekuriteit",
    "SMTP Port" : "SMTP-poort",
    "SMTP User" : "SMTP-gebruiker",
    "SMTP Password" : "SMTP-wagwoord",
    "Account settings" : "Rekeninginstellings",
    "Aliases" : "Aliasse",
    "Signature" : "Handtekening",
    "Default folders" : "Verstekvouers",
    "Mail server" : "E-posbediener",
    "Go back" : "Gaan terug",
    "Email address" : "E-posadres",
    "Cancel" : "Kanselleer",
    "Add mail account" : "Voeg posrekening toe",
    "General" : "Algemeen",
    "Register" : "Registreer",
    "About" : "Aangaande",
    "Keyboard shortcuts" : "Sneltoetse",
    "Archive" : "Argief",
    "Delete" : "Skrap",
    "Search" : "Soek",
    "Send" : "Stuur",
    "Refresh" : "Verfris",
    "No certificate" : "Geen sertifikaat",
    "Certificate updated" : "Sertifikaat bygewerk",
    "Could not update certificate" : "Kon nie sertifikaat bywerk nie",
    "{commonName} - Valid until {expiryDate}" : "{commonName} - Geldig tot {expiryDate}",
    "Update Certificate" : "Werk sertifikaat by",
    "Send later" : "Stuur later",
    "From" : "Van",
    "Select account" : "Kies rekening",
    "To" : "Aan",
    "Contact or email address …" : "Kontak of e-posadres …",
    "Subject" : "Onderwerp",
    "Write message …" : "Skryf boodskap…",
    "Send now" : "Stuur nou",
    "Tomorrow morning" : "Môreoggend",
    "Tomorrow afternoon" : "Môremiddag",
    "Monday morning" : "Maandagoggend",
    "Custom date and time" : "Pasgemaakte datum en tyd",
    "Enter a date" : "Voer ’n datum in",
    "Choose" : "Kies",
    "Confirm" : "Bevestig",
    "Plain text" : "Skoonteks",
    "No subject" : "Geen onderwerp",
    "Favorite" : "Gunsteling",
    "Back" : "Terug",
    "All day" : "Heeldag",
    "Description" : "Beskrywing",
    "Create" : "Skep",
    "Select" : "Kies",
    "Comment" : "Kommentaar",
    "Accept" : "Aanvaar",
    "Remove" : "Verwyder",
    "email" : "e-pos",
    "Other" : "Ander",
    "Forward" : "Stuur aan",
    "View source" : "Bekyk bron",
    "Message body" : "Boodskaplyfteks",
    "Unnamed" : "Naamloos",
    "Import into calendar" : "Voer in na kalender",
    "Download attachment" : "Laai aanhangsel af",
    "Move" : "Skuif",
    "Loading …" : "Laai …",
    "Remove account" : "Verwyder rekening",
    "Quota" : "Kwota",
    "Saving" : "Stoor tans",
    "New message" : "Nuwe boodskap",
    "Reply" : "Antwoord",
    "Retry" : "Herprobeer",
    "Sending …" : "Stuur…",
    "Add" : "Voeg by",
    "Date" : "Datum",
    "Tags" : "Etikette",
    "Custom" : "Eie",
    "Message source" : "Boodskapbron",
    "Actions" : "Aksies",
    "Priority" : "Prioriteit",
    "Reset" : "Herstel",
    "Client ID" : "Kliënt-ID",
    "User" : "Gebruiker",
    "Host" : "Gasheer",
    "Port" : "Poort",
    "Valid until" : "Geldig tot",
    "Certificate" : "Sertifikaat",
    "Submit" : "Dien in",
    "Connect your mail account" : "Koppel u posrekening",
    "All" : "Alle",
    "Drafts" : "Konsepte",
    "Favorites" : "Gunstelinge",
    "All inboxes" : "Alle inkassies",
    "Inbox" : "Inkassie",
    "Junk" : "Gemorspos",
    "Sent" : "Gestuur",
    "Trash" : "Asblik",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Forwarding to %s" : "Stuur aan na %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klik hier indien u nie binne die volgende paar sekondes outomaties herverwys word nie.",
    "Redirect" : "Herverwys",
    "The link leads to %s" : "Die skakel lei na %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-5.1.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/af.js <==
OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Ingebedde boodskap %s",
    "Important mail" : "Belangrike pos",
    "Unread mail" : "Ongeleesde pos",
    "Important" : "Belangrik",
    "Work" : "Werk",
    "Personal" : "Persoonlik",
    "To Do" : "Moet doen",
    "Later" : "Later",
    "Mail" : "Pos",
    "Mails" : "E-pos",
    "💌 A mail app for Nextcloud" : "💌 ’n E-postoep vir Nextcloud",
    "Save" : "Stoor",
    "Connect" : "Verbind",
    "Name" : "Naam",
    "Mail address" : "Posadres",
    "Password" : "Wagwoord",
    "Manual" : "Handmatig",
    "IMAP Settings" : "IMAP-instellings",
    "IMAP Host" : "IMAP-gasheer",
    "IMAP Security" : "IMAP-sekuriteit",
    "None" : "Geen",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-poort",
    "IMAP User" : "IMAP-gebruiker",
    "IMAP Password" : "IMAP-wagwoord",
    "SMTP Settings" : "SMTP-instellings",
    "SMTP Host" : "SMTP-gasheer",
    "SMTP Security" : "SMTP-sekuriteit",
    "SMTP Port" : "SMTP-poort",
    "SMTP User" : "SMTP-gebruiker",
    "SMTP Password" : "SMTP-wagwoord",
    "Account settings" : "Rekeninginstellings",
    "Aliases" : "Aliasse",
    "Signature" : "Handtekening",
    "Default folders" : "Verstekvouers",
    "Mail server" : "E-posbediener",
    "Go back" : "Gaan terug",
    "Email address" : "E-posadres",
    "Cancel" : "Kanselleer",
    "Add mail account" : "Voeg posrekening toe",
    "General" : "Algemeen",
    "Register" : "Registreer",
    "About" : "Aangaande",
    "Keyboard shortcuts" : "Sneltoetse",
    "Archive" : "Argief",
    "Delete" : "Skrap",
    "Search" : "Soek",
    "Send" : "Stuur",
    "Refresh" : "Verfris",
    "No certificate" : "Geen sertifikaat",
    "Certificate updated" : "Sertifikaat bygewerk",
    "Could not update certificate" : "Kon nie sertifikaat bywerk nie",
    "{commonName} - Valid until {expiryDate}" : "{commonName} - Geldig tot {expiryDate}",
    "Update Certificate" : "Werk sertifikaat by",
    "Send later" : "Stuur later",
    "From" : "Van",
    "Select account" : "Kies rekening",
    "To" : "Aan",
    "Contact or email address …" : "Kontak of e-posadres …",
    "Subject" : "Onderwerp",
    "Write message …" : "Skryf boodskap…",
    "Send now" : "Stuur nou",
    "Tomorrow morning" : "Môreoggend",
    "Tomorrow afternoon" : "Môremiddag",
    "Monday morning" : "Maandagoggend",
    "Custom date and time" : "Pasgemaakte datum en tyd",
    "Enter a date" : "Voer ’n datum in",
    "Choose" : "Kies",
    "Confirm" : "Bevestig",
    "Plain text" : "Skoonteks",
    "No subject" : "Geen onderwerp",
    "Favorite" : "Gunsteling",
    "Back" : "Terug",
    "All day" : "Heeldag",
    "Description" : "Beskrywing",
    "Create" : "Skep",
    "Select" : "Kies",
    "Comment" : "Kommentaar",
    "Accept" : "Aanvaar",
    "Remove" : "Verwyder",
    "email" : "e-pos",
    "Other" : "Ander",
    "Forward" : "Stuur aan",
    "View source" : "Bekyk bron",
    "Message body" : "Boodskaplyfteks",
    "Unnamed" : "Naamloos",
    "Import into calendar" : "Voer in na kalender",
    "Download attachment" : "Laai aanhangsel af",
    "Move" : "Skuif",
    "Loading …" : "Laai …",
    "Remove account" : "Verwyder rekening",
    "Quota" : "Kwota",
    "Saving" : "Stoor tans",
    "New message" : "Nuwe boodskap",
    "Reply" : "Antwoord",
    "Retry" : "Herprobeer",
    "Add" : "Voeg by",
    "Date" : "Datum",
    "Tags" : "Etikette",
    "Custom" : "Eie",
    "Message source" : "Boodskapbron",
    "Recipient" : "Ontvanger",
    "Priority" : "Prioriteit",
    "Reset" : "Herstel",
    "Client ID" : "Kliënt-ID",
    "User" : "Gebruiker",
    "Host" : "Gasheer",
    "Port" : "Poort",
    "Valid until" : "Geldig tot",
    "Certificate" : "Sertifikaat",
    "Submit" : "Dien in",
    "Connect your mail account" : "Koppel u posrekening",
    "All" : "Alle",
    "Drafts" : "Konsepte",
    "Favorites" : "Gunstelinge",
    "All inboxes" : "Alle inkassies",
    "Inbox" : "Inkassie",
    "Junk" : "Gemorspos",
    "Sent" : "Gestuur",
    "Trash" : "Asblik",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Forwarding to %s" : "Stuur aan na %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klik hier indien u nie binne die volgende paar sekondes outomaties herverwys word nie.",
    "Redirect" : "Herverwys",
    "The link leads to %s" : "Die skakel lei na %s",
    "Actions" : "Aksies"
},
"nplurals=2; plural=(n != 1);");
